@@ -1,6 +1,7 @@
 """
 Tests for the 'toolchain' transforms.
 """
+import os.path
 from pprint import pprint
 
 import pytest
@@ -8,6 +9,8 @@ import pytest
 from taskgraph.transforms.job import make_task_description
 from taskgraph.util.templates import merge
 
+here = os.path.abspath(os.path.dirname(__file__))
+
 TASK_DEFAULTS = {
     "description": "fake description",
     "label": "fake-task-label",
@@ -19,14 +22,17 @@ TASK_DEFAULTS = {
     },
     "run": {
         "using": "run-task",
-        "command": "echo hello world",
+        "command": "echo hello {extra_string}",
+        "command-context": {
+            "from-file": f"{here}/data/command_context.yaml",
+        },
     },
 }
 
 
 @pytest.fixture
 def run_job_using(mocker, run_transform):
-    m = mocker.patch("taskgraph.util.hash._find_files")
+    m = mocker.patch("taskgraph.util.hash._get_all_files")
     m.return_value = [
         "taskcluster/scripts/toolchain/run.sh",
         "taskcluster/scripts/toolchain/run.ps1",
